@@ -17,9 +17,6 @@ if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
-
-import sys
-
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -256,7 +253,16 @@ EventTypeDef = TypedDict(
 
 IBMDb2SettingsTypeDef = TypedDict(
     "IBMDb2SettingsTypeDef",
-    {"DatabaseName": str, "Password": str, "Port": int, "ServerName": str, "Username": str},
+    {
+        "DatabaseName": str,
+        "Password": str,
+        "Port": int,
+        "ServerName": str,
+        "SetDataCaptureChanges": bool,
+        "CurrentLsn": str,
+        "MaxKBytesPerRead": int,
+        "Username": str,
+    },
     total=False,
 )
 
@@ -295,7 +301,22 @@ KinesisSettingsTypeDef = TypedDict(
 
 MicrosoftSQLServerSettingsTypeDef = TypedDict(
     "MicrosoftSQLServerSettingsTypeDef",
-    {"Port": int, "DatabaseName": str, "Password": str, "ServerName": str, "Username": str},
+    {
+        "Port": int,
+        "BcpPacketSize": int,
+        "DatabaseName": str,
+        "ControlTablesFileGroup": str,
+        "Password": str,
+        "ReadBackupOnly": bool,
+        "SafeguardPolicy": Literal[
+            "rely-on-sql-server-replication-agent",
+            "exclusive-automatic-truncation",
+            "shared-automatic-truncation",
+        ],
+        "ServerName": str,
+        "Username": str,
+        "UseBcpFullLoad": bool,
+    },
     total=False,
 )
 
@@ -320,7 +341,19 @@ MongoDbSettingsTypeDef = TypedDict(
 
 MySQLSettingsTypeDef = TypedDict(
     "MySQLSettingsTypeDef",
-    {"DatabaseName": str, "Password": str, "Port": int, "ServerName": str, "Username": str},
+    {
+        "AfterConnectScript": str,
+        "DatabaseName": str,
+        "EventsPollInterval": int,
+        "TargetDbType": Literal["specific-database", "multiple-databases"],
+        "MaxFileSize": int,
+        "ParallelLoadThreads": int,
+        "Password": str,
+        "Port": int,
+        "ServerName": str,
+        "ServerTimezone": str,
+        "Username": str,
+    },
     total=False,
 )
 
@@ -347,12 +380,32 @@ class NeptuneSettingsTypeDef(_RequiredNeptuneSettingsTypeDef, _OptionalNeptuneSe
 OracleSettingsTypeDef = TypedDict(
     "OracleSettingsTypeDef",
     {
+        "AddSupplementalLogging": bool,
+        "ArchivedLogDestId": int,
+        "AdditionalArchivedLogDestId": int,
+        "AllowSelectNestedTables": bool,
+        "ParallelAsmReadThreads": int,
+        "ReadAheadBlocks": int,
+        "AccessAlternateDirectly": bool,
+        "UseAlternateFolderForOnline": bool,
+        "OraclePathPrefix": str,
+        "UsePathPrefix": str,
+        "ReplacePathPrefix": bool,
+        "EnableHomogenousTablespace": bool,
+        "DirectPathNoLog": bool,
+        "ArchivedLogsOnly": bool,
         "AsmPassword": str,
         "AsmServer": str,
         "AsmUser": str,
+        "CharLengthSemantics": Literal["default", "char", "byte"],
         "DatabaseName": str,
+        "DirectPathParallelLoad": bool,
+        "FailTasksOnLobTruncation": bool,
+        "NumberDatatypeScale": int,
         "Password": str,
         "Port": int,
+        "ReadTableSpaceName": bool,
+        "RetryInterval": int,
         "SecurityDbEncryption": str,
         "SecurityDbEncryptionName": str,
         "ServerName": str,
@@ -392,7 +445,20 @@ PendingMaintenanceActionTypeDef = TypedDict(
 
 PostgreSQLSettingsTypeDef = TypedDict(
     "PostgreSQLSettingsTypeDef",
-    {"DatabaseName": str, "Password": str, "Port": int, "ServerName": str, "Username": str},
+    {
+        "AfterConnectScript": str,
+        "CaptureDdls": bool,
+        "MaxFileSize": int,
+        "DatabaseName": str,
+        "DdlArtifactsSchema": str,
+        "ExecuteTimeout": int,
+        "FailTasksOnLobTruncation": bool,
+        "Password": str,
+        "Port": int,
+        "ServerName": str,
+        "Username": str,
+        "SlotName": str,
+    },
     total=False,
 )
 
@@ -626,6 +692,11 @@ S3SettingsTypeDef = TypedDict(
         "TimestampColumnName": str,
         "ParquetTimestampInMillisecond": bool,
         "CdcInsertsAndUpdates": bool,
+        "DatePartitionEnabled": bool,
+        "DatePartitionSequence": Literal[
+            "YYYYMMDD", "YYYYMMDDHH", "YYYYMM", "MMYYYYDD", "DDMMYYYY"
+        ],
+        "DatePartitionDelimiter": Literal["SLASH", "UNDERSCORE", "DASH", "NONE"],
     },
     total=False,
 )
